#!/bin/bash

# Chemin vers le répertoire contenant les fichiers CSV
csv_dir="$(dirname \"$0\")/../data"

# Exclure le fichier CSV modifié le jour même
exclude_today="-not -newermt $(date +%Y-%m-%d)"

# Trouver tous les fichiers CSV dans le répertoire, à l'exception de celui modifié le jour même
csv_files=$(find "$csv_dir" -maxdepth 1 -type f -iname '*.csv' $exclude_today)

# URL du script PHP qui gère les fichiers CSV
php_script="http://ampere.rpiluc001.acegrp.lan/upload.php"

# Vérifier si le dossier "done/" existe
if [ ! -d "$csv_dir/done" ]
then
  # Créer le dossier "done/"
  mkdir "$csv_dir/done"
fi

# Parcourir le répertoire des fichiers CSV
for file in $csv_files
do
  # Calculer le CRC du fichier
  crc=$(sha1sum "$file" | awk '{print $1}')

  # Envoyer le fichier CSV et le CRC au script PHP via cURL
  output=$(curl -F "file=@$file" $php_script)

  # Vérifier la réponse du script PHP
  if [ "$output" = "$crc" ]
  then
    # Déplacer le fichier CSV dans le dossier "done/"
    mv "$file" "$csv_dir/done/"
    echo "Le fichier $file a été correctement traité."
  else
    echo "Une erreur s'est produite lors du traitement du fichier $file."
  fi
done
